package dao

import (
	"contract_backend/contract/aon_executor"
	"contract_backend/contract/aon_user"
	"crypto/ecdsa"
	"math/big"

	"github.com/ethereum/go-ethereum/accounts/abi/bind"
	"github.com/ethereum/go-ethereum/common"
)

func (d *Dao) Login(privateKey *ecdsa.PrivateKey, userId string, inviter string) (txHash common.Hash, err error) {
	instance, err := aon_user.NewAonUser(common.HexToAddress(d.c.Chain.UserContract), d.ethClient)
	if err != nil {
		return common.Hash{}, err
	}

	auth, err := bind.NewKeyedTransactorWithChainID(privateKey, d.chainId)
	if err != nil {
		return common.Hash{}, err
	}
	auth.GasPrice = d.gasPrice
	auth.GasLimit = 800000
	tx, err := instance.Login(auth, userId, inviter)
	if err != nil {
		return common.Hash{}, err
	}
	return tx.Hash(), nil
}

func (d *Dao) ExecuteTask(privateKey *ecdsa.PrivateKey, executeId, userId, appId string, modelIds []string, price *big.Int) (txHash common.Hash, err error) {
	instance, err := aon_executor.NewAonExecutor(common.HexToAddress(d.c.Chain.UserContract), d.ethClient)
	if err != nil {
		return common.Hash{}, err
	}

	auth, err := bind.NewKeyedTransactorWithChainID(privateKey, d.chainId)
	if err != nil {
		return common.Hash{}, err
	}
	auth.GasPrice = d.gasPrice
	tx, err := instance.ExecuteByUserId(auth, executeId, userId, appId, modelIds, price)
	if err != nil {
		return common.Hash{}, err
	}
	return tx.Hash(), nil
}
